@@ -215,6 +215,15 @@ class AnnotatedSentence(Sentence):
         """
         self.writeToFile(self.__fileName)
 
+    def getUniversalDependencyFormat(self) -> str:
+        result = "# sent_id = " + self.getFileName() + "\n" + "# text = " + self.toString() + "\n"
+        for i in range(self.wordCount()):
+            word = self.getWord(i)
+            if isinstance(word, AnnotatedWord):
+                result += str(i + 1) + "\t" + word.getUniversalDependencyFormat(self.wordCount()) + "\n"
+        result += "\n"
+        return result
+
     def constructLiterals(self, wordNet: WordNet, fsm: FsmMorphologicalAnalyzer, wordIndex: int) -> list:
         """
         Creates a list of literal candidates for the i'th word in the sentence. It combines the results of
